@@ -1,15 +1,13 @@
 import logging
 import requests
+import urllib3
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
 
 requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
-logging.basicConfig(level=logging.INFO)
+urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 logging.getLogger('requests').setLevel(logging.WARNING)
-logging.getLogger('alembic').setLevel(logging.WARNING)
 logging.getLogger('zeep').setLevel(logging.WARNING)
 logging.getLogger('httpstream').setLevel(logging.WARNING)
-logging.getLogger('celery').setLevel(logging.WARNING)
-
-
-# Register signal handlers
-from . import signals  # noqa
+logging.getLogger('urllib3').setLevel(logging.WARNING)
+logging.getLogger('rdflib').setLevel(logging.WARNING)
+logging.getLogger('chardet').setLevel(logging.WARNING)
