@@ -1,6 +1,6 @@
 import re
 from urllib.parse import urlparse
-from celestial import normalize_mimetype
+from pantomime import normalize_mimetype
 
 from memorious.logic.mime import GROUPS
 
@@ -13,7 +13,7 @@ class Rule(object):
         pass
 
     def apply(self, res):
-        raise NotImplemented()
+        raise NotImplementedError
 
     def to_dict(self):
         return self.value
@@ -90,7 +90,7 @@ class MimeTypeRule(Rule):
         self.clean = normalize_mimetype(self.value)
 
     def apply(self, res):
-        return self.res.content_type == self.clean
+        return res.content_type == self.clean
 
 
 class MimeGroupRule(Rule):
