@@ -3,19 +3,20 @@ import uuid
 import shutil
 import logging
 import time
+import random
 from copy import deepcopy
 from tempfile import mkdtemp
 from contextlib import contextmanager
 from servicelayer.cache import make_key
 from servicelayer.util import load_json, dump_json
 
-from memorious.core import manager, storage, conn
-from memorious.core import datastore
+from memorious.core import manager, storage, tags, datastore
 from memorious.model import Event, Queue, Crawl
 from memorious.logic.http import ContextHttp
 from memorious.logic.check import ContextCheck
 from memorious.util import random_filename
 from memorious.exc import QueueTooBigError
+from memorious import settings
 
 
 class Context(object):
@@ -52,6 +53,13 @@ class Context(object):
         if stage is None or stage not in self.crawler.stages:
             self.log.info("No next stage: %s (%s)" % (stage, rule))
             return
+        if settings.DEBUG:
+            # sampling rate is a float between 0.0 to 1.0. If it's 0.2, we
+            # aim to execute only 20% of the crawler's tasks.
+            sampling_rate = self.get('sampling_rate')
+            if sampling_rate and random.random() > float(sampling_rate):
+                self.log.info("Skipping emit due to sampling rate")
+                return
         state = self.dump_state()
         delay = delay or self.params.get('delay', 0) or self.crawler.delay
         self.sleep(delay)
@@ -116,15 +124,15 @@ class Context(object):
     def set_tag(self, key, value):
         data = dump_json(value)
         key = make_key(self.crawler, "tag", key)
-        return conn.set(key, data, ex=self.crawler.expire)
+        return tags.set(key, data)
 
     def get_tag(self, key):
-        value = conn.get(make_key(self.crawler, "tag", key))
+        value = tags.get(make_key(self.crawler, "tag", key))
         if value is not None:
             return load_json(value)
 
     def check_tag(self, key):
-        return conn.exists(make_key(self.crawler, "tag", key))
+        return tags.exists(make_key(self.crawler, "tag", key))
 
     def skip_incremental(self, *criteria):
         """Perform an incremental check on a set of criteria.
@@ -146,7 +154,7 @@ class Context(object):
         if self.check_tag(key):
             return True
 
-        self.set_tag(key, None)
+        self.set_tag(key, 'inc')
         return False
 
     def store_file(self, file_path, content_hash=None):
