@@ -1,19 +1,18 @@
 import os
-from random import randint
+import uuid
 
 import pytest
 
+from memorious import settings
 from memorious.logic.manager import CrawlerManager
 from memorious.logic.context import Context
 from memorious.logic.http import ContextHttp
-from memorious.core import ensure_db
 
 
-ensure_db()
+settings.TESTING = True
 
 
-@pytest.fixture(scope="module")
-def crawler_dir():
+def get_crawler_dir():
     file_path = os.path.realpath(__file__)
     crawler_dir = os.path.normpath(os.path.join(
         file_path, "../testdata/config"
@@ -22,32 +21,52 @@ def crawler_dir():
 
 
 @pytest.fixture(scope="module")
-def manager():
+def crawler_dir():
+    return get_crawler_dir()
+
+
+def get_manager():
     manager = CrawlerManager()
-    manager.load_path(crawler_dir())
+    manager.load_path(get_crawler_dir())
+    settings._manager = manager
     return manager
 
 
 @pytest.fixture(scope="module")
-def crawler():
-    return manager().get("occrp_web_site")
+def manager():
+    return get_manager()
+
+
+def get_crawler():
+    return get_manager().get("occrp_web_site")
 
 
 @pytest.fixture(scope="module")
-def stage():
-    cr = crawler()
+def crawler():
+    return get_crawler()
+
+
+def get_stage():
+    cr = get_crawler()
     return cr.get(cr.init_stage)
 
 
 @pytest.fixture(scope="module")
-def context():
-    ctx = Context(crawler(), stage(), {"foo": "bar"})
-    # Assign a fake operation id, so that the DB doesn't complain about
-    # NotNullContraint while saving events etc.
-    ctx.operation_id = randint(1, 99999)
+def stage():
+    return get_stage()
+
+
+def get_context():
+    ctx = Context(get_crawler(), get_stage(), {"foo": "bar"})
+    ctx.run_id = str(uuid.uuid4())
     return ctx
 
 
+@pytest.fixture(scope="module")
+def context():
+    return get_context()
+
+
 @pytest.fixture(scope="module")
 def http():
-    return ContextHttp(context())
+    return ContextHttp(get_context())
